savedcmd_arch/arm/include/generated/uapi/asm/unistd-oabi.h := sh ./scripts/syscallhdr.sh --abis common,oabi --offset __NR_SYSCALL_BASE arch/arm/tools/syscall.tbl arch/arm/include/generated/uapi/asm/unistd-oabi.h
